@@ -16,7 +16,7 @@ class TikApi(object):
             return 'Missing required parameters. DM Virtuality.#6670 for proper instruction.'
         elif resp['status'] == 5:
             return resp['result']['xss']
-    except JSONDecodeError:
+    except json.decoder.JSONDecodeError:
         return 'Invalid parameter has been received.'
 
   def xgorgon(self, url, cookies):
@@ -30,7 +30,7 @@ class TikApi(object):
             return 'Missing required parameters. DM Virtuality.#6670 for proper instruction.'
         elif resp['status'] == 5:
             return resp['result']['gorgon']
-    except JSONDecodeError:
+    except json.decoder.JSONDecodeError:
         return 'Invalid parameter has been received.'
 
   def xkhronos(self, url, cookies):
@@ -44,5 +44,5 @@ class TikApi(object):
             return 'Missing required parameters. DM Virtuality.#6670 for proper instruction.'
         elif resp['status'] == 5:
             return resp['result']['khronos']
-    except JSONDecodeError:
+    except json.decoder.JSONDecodeError:
         return 'Invalid parameter has been received.'
\ No newline at end of file
